#!/usr/local/bin/gnuplot
set terminal pdf enhanced size 18cm,12cm
set output 'fig/perf-overview.pdf'
#set terminal pngcairo size 600,400
#set output 'test.png'

set loadpath './'
load 'palette.pal'

set border 3 front lt black linewidth 1.000 dashtype solid
set boxwidth 0.8 absolute
set style fill   solid 1.00 noborder
set grid nopolar
set grid noxtics nomxtics ytics nomytics noztics nomztics nortics nomrtics \
 nox2tics nomx2tics y2tics nomy2tics nocbtics nomcbtics
set grid layerdefault   lt 0 linecolor 0 linewidth 0.500,  lt 0 linecolor 0 linewidth 0.500

set key bmargin center horizontal Left reverse noenhanced autotitle columnhead nobox
set style histogram rowstacked title textcolor lt -1 offset character 2, 0.25
set datafile missing '-'
set style data histograms
set xtics border in scale 0,0 nomirror rotate by -45  autojustify
set xtics  norangelimit  font ",8"
set xtics   ()
set ytics border in scale 0,0 mirror norotate  autojustify
set y2tics border in scale 0,0 mirror norotate  autojustify textcolor rgb color8
set ytics  norangelimit autofreq  font ",8"
set y2tics  norangelimit autofreq  font ",8"
set ztics border in scale 0,0 nomirror norotate  autojustify
set cbtics border in scale 0,0 mirror norotate  autojustify
set rtics axis in scale 0,0 nomirror norotate  autojustify
set xlabel  offset character 0, -2, 0 font "" textcolor lt -1 norotate
set xrange [ * : * ] noreverse writeback
set x2range [ * : * ] noreverse writeback
set y2range [ 0.0 : * ] noreverse writeback
set zrange [ * : * ] noreverse writeback
set cbrange [ * : * ] noreverse writeback
set rrange [ * : * ] noreverse writeback
set colorbox vertical origin screen 0.9, 0.2 size screen 0.05, 0.6 front  noinvert bdefault
NO_ANIMATION = 1

# Set the range of the Y-axis and the format of the labels
set format y '%.2f s'
set format y2 '%.2f s'
set yrange [ 0.0 : 0.2 ] noreverse writeback

set title "Iteration time for different versions of the D3Q27 proxy application on various simulation domains"
set xlabel "Environment model"
set ylabel "Time/iteration"

set datafile separator ','

## Last datafile plotted: "immigration.dat"
plot newhistogram "RCA", './data/perf-r4-400-fram-comb.csv' \
  using "collide_rca":xtic(1) t "Collide" lc rgb bugn8, \
  '' u "stream_rca" t "Stream" lc rgb bugn6, \
  '' u "exchange_rca" t "Exchange" lc rgb bugn4, \
  '' u "exchange_rca":($2+0.09):(sprintf("%.2f", $2+$3+$4)) with labels notitle offset 3,1.5, \
  newhistogram "100% porosity", \
  '' u "collide_p100":xtic(1) t "Collide" axes x1y2 lc rgb color8, \
  '' u "stream_p100" t "Stream" axes x1y2 lc rgb color6, \
  '' u "exchange_p100" t "Exchange" axes x1y2 lc rgb color4, \
  newhistogram "80% porosity", \
  '' u "collide_p80":xtic(1) notitle axes x1y2 lc rgb color8, \
  '' u "stream_p80" notitle axes x1y2 lc rgb color6, \
  '' u "exchange_p80" notitle axes x1y2 lc rgb color4, \
  newhistogram "60% porosity", \
  '' u "collide_p60":xtic(1) notitle axes x1y2 lc rgb color8, \
  '' u "stream_p60" notitle axes x1y2 lc rgb color6, \
  '' u "exchange_p60" notitle axes x1y2 lc rgb color4, \
  newhistogram "10% porosity", \
  '' u "collide_p10":xtic(1) notitle axes x1y2 lc rgb color8, \
  '' u "stream_p10" notitle axes x1y2 lc rgb color6, \
  '' u "exchange_p10" notitle axes x1y2 lc rgb color4, \

set output


# Plot the data using the remaining three columns as stacked bars
#plot './data/density-IALO-400-comb.csv' \
  #using 2:xticlabels(1) lc rgb color8 title 'Collide', \
  #'' using 3 lc rgb color6 title 'Stream', \
  #'' using 4 lc rgb color4 title 'Border exchange', \
