#!/usr/local/bin/gnuplot -persist
set terminal pdf enhanced
set output 'fig/RCA-solid-1024-idun-ranks.pdf'
#set terminal pngcairo size 600,400
#set output 'test.png'

set loadpath './'
load 'palette.pal'


set border 3 front lt black linewidth 1.000 dashtype solid
set boxwidth 0.8 absolute
set style fill solid 1.00 noborder
set grid nopolar
set grid noxtics nomxtics ytics nomytics noztics nomztics nortics nomrtics \
 nox2tics nomx2tics noy2tics nomy2tics nocbtics nomcbtics
set grid layerdefault  lt 0 linecolor 0 linewidth 0.500,  lt 0 linecolor 0 linewidth 0.500
set key bmargin center horizontal Left reverse noenhanced autotitle columnhead nobox
set style histogram rowstacked title textcolor lt -1 offset character 2, 0.2
unset parametric
set datafile missing '-'
set style data histograms
set xtics border in scale 0,0 nomirror  autojustify
#set xtics  norangelimit  font ",8"
set xtics   ()
set ytics border in scale 0,0 mirror norotate  autojustify
set ytics norangelimit autofreq  font ",8"
set ztics border in scale 0,0 nomirror norotate  autojustify
set cbtics border in scale 0,0 mirror norotate  autojustify
set rtics axis in scale 0,0 nomirror norotate  autojustify

# Set the labels for the X and Y axes and the title of the graph
set xlabel 'Ranks'
set ylabel 'Runtime'

# Set the range of the Y-axis and the format of the labels
set yrange [0:*]
set format y '%.2f s'

set colorbox vertical origin screen 0.9, 0.2 size screen 0.05, 0.6 front  noinvert bdefault

set datafile separator ','


#plot './data/scale-base-RCA1024-fram-comb.csv' \
  #using 3:xticlabels(1) lc rgb color8 title 'Collide', \
  #'' using 4 lc rgb color6 title 'Stream', \
  #'' using 5 lc rgb color4 title 'Border exchange'

set output

#####################

set title "RCA with 1024 node width [IALO]"
set output 'fig/RCA-solid-1024-fram-ranks-optimized.pdf'

plot './data/scale-IALO-RCA1024-fram-comb.csv' \
  using 3:xticlabels(1) lc rgb color8 title 'Collide', \
  '' using 4 lc rgb color6 title 'Stream', \
  '' using 5 lc rgb color4 title 'Border exchange'

######################

set title "RCA with 1024 node width [IALO 1D]"
set output 'fig/RCA-solid-1024-fram-ranks-IALO1D.pdf'

plot './data/scale-IALO1D-RCA1024-fram-comb.csv' \
  using 3:xticlabels(1) lc rgb color8 title 'Collide', \
  '' using 4 lc rgb color6 title 'Stream', \
  '' using 5 lc rgb color4 title 'Border exchange'

######################


set title "RCA with 1024 node width [base]"
set output 'fig/RCA-solid-1024-idun-ranks-baseline.pdf'

plot './data/RCA-solid-1024-idun-baseline-comb.csv' \
  using 3:xticlabels(1) lc rgb color8 title 'Collide', \
  '' using 4 lc rgb color6 title 'Stream', \
  '' using 5 lc rgb color4 title 'Border exchange'


####################

# RCA 400

set title "RCA with 400 node width [IALO]"
set output 'fig/scale-RCA-400-IALO-fram.pdf'

plot './data/scale-IALO-RCA400-fram-comb.csv' \
  using 3:xticlabels(1) lc rgb color8 title 'Collide', \
  '' using 4 lc rgb color6 title 'Stream', \
  '' using 5 lc rgb color4 title 'Border exchange'



#####################
#####################
#####################


set style histogram clustered title textcolor lt -1 offset character 2, 0.2

set output 'fig/RCA-solid-1024-idun-ranks-comp.pdf'

plot './data/scale-IALO-RCA1024-fram-comb.csv' \
    using 6:xticlabels(1) lc rgb color8 title 'Optimized', \
 './data/RCA-solid-1024-idun-baseline-comb.csv' \
    using 6 lc rgb color7 title 'Baseline', \

set output
