#ifndef __READ_BINVOX_H
#define __READ_BINVOX_H

struct Binvox_content;

struct Binvox_content
{
  int height;
  int width;
  int depth;

  int translate_x;
  int translate_y;
  int translate_z;
  int scale_factor;

  char* data;
};

typedef struct Binvox_content Binvox_content;

/* Get a value from the voxel map, macro to compute the index from coordinates
 * i = y
 * j = x
 * k = z
 */
#define VOXEL_MAP(voxel_content, i, j, k)                                      \
  voxel_content->data[((j) * (voxel_content->depth * voxel_content->height)) + \
                      (i) * (voxel_content->depth) + (k)]

/* Read and parse a binvox file pointed to by `filename` and store the contents
 * in the address contained in `contents.data`.
 *
 * contents.data is a pointer to the voxel data. It must be freed by the user.
 * If non-zero return, `contents.data` is freed by the callee.
 */
int
read_binvox(char* filename, Binvox_content* contents);

/*
 * Write to a binvox file.
 */
int
write_binvox(char* filename, Binvox_content* contents);

#endif
